@@ -1,7 +1,7 @@
 import logging
 from sparrow_cloud.restclient import rest_client
 from sparrow_cloud.restclient.exception import HTTPException
-from sparrow_cloud.utils.get_settings_value import get_settings_value
+from sparrow_cloud.utils.get_cm_value import get_cm_value
 logger = logging.getLogger(__name__)
 
 
@@ -10,15 +10,15 @@ def access_verify(user_id, app_name, resource_code):
     access control verify
     """
     if all([user_id, app_name, resource_code]):
-        service_conf = get_settings_value("ACCESS_CONTROL").get("ACCESS_CONTROL_SERVICE")
-        api_path = get_settings_value("ACCESS_CONTROL").get("VERIFY_API_PATH")
+        sc_access_control_svc = get_cm_value("SC_ACCESS_CONTROL_SVC")
+        sc_access_control_api = get_cm_value("SC_ACCESS_CONTROL_API")
         params = {
             "user_id": user_id,
             "app_name": app_name,
             "resource_code": resource_code
         }
         try:
-            response = rest_client.get(service_conf, api_path=api_path, timeout=0.5, params=params)
+            response = rest_client.get(sc_access_control_svc, api_path=sc_access_control_api, params=params)
             if response['has_perm']:
                 return True
         except HTTPException as ex:
